.. py:module:: sdr

Digital signal processing
=========================

FIR filtering
-------------

.. python-apigen-group:: dsp-fir-filtering

IIR filtering
-------------

.. python-apigen-group:: dsp-iir-filtering

Polyphase FIR filtering
-----------------------

.. python-apigen-group:: dsp-polyphase-filtering

Filter applications
-------------------

.. python-apigen-group:: dsp-filter-applications

Arbitrary resampling
--------------------

.. python-apigen-group:: dsp-arbitrary-resampling

Correlation
-----------

.. python-apigen-group:: dsp-correlation

Signal manipulation
-------------------

.. python-apigen-group:: dsp-signal-manipulation
